@@ -525,9 +525,9 @@ class CloudvectorDAST(object):
     def _create_assertions_map(self, url, params, req_payload, resp_payload):
         assertions_map = {}
         if url not in self.assertions_map:
-            url = url.replace("//","/").replace("/", "_S_").replace("{", "").replace("}", "").replace(" ","").split("?")[0]
-            if url.startswith("_S_"):
-                url = "_"+url[3:]
+            url = url.replace("//","/").replace("/", "__").replace("{", "").replace("}", "").replace(" ","").split("?")[0]
+            if url.startswith("__"):
+                url = "_"+url[2:]
             self.assertions_map[url] = {}
         if None in params:
             params.remove(None)
@@ -585,7 +585,7 @@ class CloudvectorDAST(object):
             if event["url"]:
                 # api = str(event["http-req-url"]).lstrip("/").rstrip("/").replace("/", "_").replace("-", "_").split("?")[
                 #     0]
-                api = str(event["http-req-url"]).lstrip("/").replace("/", "_S_").replace(" ","").split("?")[0]
+                api = str(event["http-req-url"]).lstrip("/").replace("/", "__").replace(" ","").split("?")[0]
                 if api not in apis_to_be_tested:
                     apis_to_be_tested[api] = {}
                 #apis_to_be_tested[api]["method"] = event["method"]
@@ -698,7 +698,7 @@ class CloudvectorDAST(object):
             if event["url"]:
                 # api = str(event["http-req-url"]).lstrip("/").rstrip("/").replace("/", "_").replace("-", "_").split("?")[
                 #     0]
-                api = str(event["http-req-url"]).lstrip("/").replace("/", "_S_").replace(" ","").split("?")[0]
+                api = str(event["http-req-url"]).lstrip("/").replace("/", "__").replace(" ","").split("?")[0]
                 if api not in apis_to_be_tested:
                     apis_to_be_tested[api] = {}
                 #apis_to_be_tested[api]["method"] = event["method"]
